==> nextcloud-22.2.6.tgz: nextcloud/apps/dav/l10n/eo.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendaro",
    "Todos" : "Taskoj",
    "Personal" : "Persona",
    "{actor} created calendar {calendar}" : "{actor} kreis kalendaron {calendar}",
    "You created calendar {calendar}" : "Vi kreis kalendaron {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} forigis kalendaron {calendar}",
    "You deleted calendar {calendar}" : "Vi forigis kalendaron {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ĝisdatigis kalendaron {calendar}",
    "You updated calendar {calendar}" : "Vi ĝisdatigis kalendaron {calendar}",
    "You shared calendar {calendar} as public link" : "Vi kunhavigis kalendaron {calendar} per publika ligilo",
    "You removed public link for calendar {calendar}" : "Vi forigis publikan ligilon por kalendaro {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} kunhavigis kalendaron {calendar} kun vi",
    "You shared calendar {calendar} with {user}" : "Vi kunhavigis kalendaron {calendar} kun {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} kunhavigis kalendaron {calendar} kun {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} malkunhavigis kalendaron {calendar} kun vi",
    "You unshared calendar {calendar} from {user}" : "Vi malkunhavigis kalendaron {calendar} kun {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} malkunhavigis kalendaron {calendar} kun {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} malkunhavigis kalendaron {calendar} kun si mem",
    "You shared calendar {calendar} with group {group}" : "Vi kunhavigis kalendaron {calendar} kun grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} kunhavigis kalendaron {calendar} kun grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Vi malkunhavigis kalendaron {calendar} kun grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} malkunhavigis kalendaron {calendar} kun grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} kreis okazaĵon {event} en kalendaro {calendar}",
    "You created event {event} in calendar {calendar}" : "Vi kreis okazaĵon {event} en kalendaro {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} forigis okazaĵon {event} en kalendaro {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vi forigis okazaĵon {event} en kalendaro {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ĝisdatigis okazaĵon {event} en kalendaro {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vi ĝisdatigis okazaĵon {event} en kalendaro {calendar}",
    "Busy" : "Okupita",
    "{actor} created todo {todo} in list {calendar}" : "{actor} kreis farendaĵon {todo} en listo {calendar}",
    "You created todo {todo} in list {calendar}" : "Vi kreis farendaĵon {todo} en listo {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} forigis farendaĵon {todo} en listo {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vi forigis farendaĵon {todo} en listo {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ĝisdatigis farendaĵon {todo} en listo {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vi ĝisdatigis farendaĵon {todo} en listo {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} plenumis farendaĵon {todo} en listo {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vi plenumis farendaĵon {todo} en listo {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} remalfermis farendaĵon {todo} en listo {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vi remalfermis farendaĵon {todo} en listo {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendaro</strong> estis modifita",
    "A calendar <strong>event</strong> was modified" : "Kalendara <strong>okazaĵo</strong> estis modifita",
    "A calendar <strong>todo</strong> was modified" : "Kalendara <strong>farendaĵo</strong> estis modifita",
    "Contact birthdays" : "Kontaktaj datrevenoj",
    "Death of %s" : "Morto de %s",
    "Calendar:" : "Kalendaro:",
    "Date:" : "Dato:",
    "Where:" : "Kie:",
    "Description:" : "Priskribo:",
    "Untitled event" : "Sentitola okazaĵo",
    "_%n year_::_%n years_" : ["%n jaro","%n jaroj"],
    "_%n month_::_%n months_" : ["%n monato","%n monatoj"],
    "_%n day_::_%n days_" : ["%n tago","%n tagoj"],
    "_%n hour_::_%n hours_" : ["%n horo","%n horoj"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutoj"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (antaŭ %s)",
    "Calendar: %s" : "Kalendaro: %s",
    "Date: %s" : "Dato: %s",
    "Description: %s" : "Priskribo: %s",
    "Where: %s" : "Kie: %s",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "Invitation canceled" : "Invito nuligita",
    "Invitation updated" : "Invito ĝisdatigita",
    "Location:" : "Loko:",
    "Link:" : "Ligilo:",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "More options …" : "Pli da opcioj...",
    "More options at %s" : "Pli da opcioj je %s",
    "Contacts" : "Kontaktoj",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Via %s uzu HTTPS, por ke vi povu uzi CalDAV kaj CardDAV kun iOS aŭ macOS.",
    "Configures a CalDAV account" : "Agordas CalDAV-konton.",
    "Configures a CardDAV account" : "Agordas CardlDAV-konton.",
    "Tasks" : "Taskoj",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-finpunkto",
    "Save" : "Konservi",
    "Calendar server" : "Kalendara servilo",
    "Send invitations to attendees" : "Sendi invitojn al ĉeestantoj",
    "Automatically generate a birthday calendar" : "Aŭtomate estigi datrevenan kalendaron",
    "Birthday calendars will be generated by a background job." : "Datrevenaj kalendaroj estos kreitaj de fona tasko.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Tial, ili disponeblos nur post kelke da tempo.",
    "Send notifications for events" : "Sendi sciigojn pri okazaĵoj",
    "Enable notifications for events via push" : "Ebligi sciigojn pri okazaĵoj per puŝteĥniko",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ankaŭ instalu la aplikaĵon {calendarappstoreopen}Kalendaro{linkclose} aŭ {calendardocopen}konektu vian surtablan kaj porteblan aparaton por eksinkronigi ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bv. certigi, ke via {emailopen}retpoŝtserva servilo{linkclose} estas bone agordita.",
    "There was an error updating your attendance status." : "Estis eraro dum ĝisdatigo de via ĉeesta stato.",
    "Please contact the organizer directly." : "Bv. senpere kontakti la organizanton.",
    "Are you accepting the invitation?" : "Ĉu vi akceptas la inviton?",
    "Tentative" : "Nekonfirmita",
    "Your attendance was updated successfully." : "Via ĉeesto sukcese ĝisdatiĝis."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.9.tgz: nextcloud/apps/dav/l10n/eo.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendaro",
    "Todos" : "Taskoj",
    "Personal" : "Persona",
    "{actor} created calendar {calendar}" : "{actor} kreis kalendaron {calendar}",
    "You created calendar {calendar}" : "Vi kreis kalendaron {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} forigis kalendaron {calendar}",
    "You deleted calendar {calendar}" : "Vi forigis kalendaron {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ĝisdatigis kalendaron {calendar}",
    "You updated calendar {calendar}" : "Vi ĝisdatigis kalendaron {calendar}",
    "You shared calendar {calendar} as public link" : "Vi kunhavigis kalendaron {calendar} per publika ligilo",
    "You removed public link for calendar {calendar}" : "Vi forigis publikan ligilon por kalendaro {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} kunhavigis kalendaron {calendar} kun vi",
    "You shared calendar {calendar} with {user}" : "Vi kunhavigis kalendaron {calendar} kun {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} kunhavigis kalendaron {calendar} kun {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} malkunhavigis kalendaron {calendar} kun vi",
    "You unshared calendar {calendar} from {user}" : "Vi malkunhavigis kalendaron {calendar} kun {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} malkunhavigis kalendaron {calendar} kun {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} malkunhavigis kalendaron {calendar} kun si mem",
    "You shared calendar {calendar} with group {group}" : "Vi kunhavigis kalendaron {calendar} kun grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} kunhavigis kalendaron {calendar} kun grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Vi malkunhavigis kalendaron {calendar} kun grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} malkunhavigis kalendaron {calendar} kun grupo {group}",
    "Untitled event" : "Sentitola okazaĵo",
    "{actor} created event {event} in calendar {calendar}" : "{actor} kreis okazaĵon {event} en kalendaro {calendar}",
    "You created event {event} in calendar {calendar}" : "Vi kreis okazaĵon {event} en kalendaro {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} forigis okazaĵon {event} en kalendaro {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vi forigis okazaĵon {event} en kalendaro {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ĝisdatigis okazaĵon {event} en kalendaro {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vi ĝisdatigis okazaĵon {event} en kalendaro {calendar}",
    "Busy" : "Okupita",
    "{actor} created todo {todo} in list {calendar}" : "{actor} kreis farendaĵon {todo} en listo {calendar}",
    "You created todo {todo} in list {calendar}" : "Vi kreis farendaĵon {todo} en listo {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} forigis farendaĵon {todo} en listo {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vi forigis farendaĵon {todo} en listo {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ĝisdatigis farendaĵon {todo} en listo {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vi ĝisdatigis farendaĵon {todo} en listo {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} plenumis farendaĵon {todo} en listo {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vi plenumis farendaĵon {todo} en listo {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} remalfermis farendaĵon {todo} en listo {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vi remalfermis farendaĵon {todo} en listo {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendaro</strong> estis modifita",
    "A calendar <strong>event</strong> was modified" : "Kalendara <strong>okazaĵo</strong> estis modifita",
    "A calendar <strong>todo</strong> was modified" : "Kalendara <strong>farendaĵo</strong> estis modifita",
    "Contact birthdays" : "Kontaktaj datrevenoj",
    "Death of %s" : "Morto de %s",
    "Calendar:" : "Kalendaro:",
    "Date:" : "Dato:",
    "Where:" : "Kie:",
    "Description:" : "Priskribo:",
    "_%n year_::_%n years_" : ["%n jaro","%n jaroj"],
    "_%n month_::_%n months_" : ["%n monato","%n monatoj"],
    "_%n day_::_%n days_" : ["%n tago","%n tagoj"],
    "_%n hour_::_%n hours_" : ["%n horo","%n horoj"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutoj"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (antaŭ %s)",
    "Calendar: %s" : "Kalendaro: %s",
    "Date: %s" : "Dato: %s",
    "Description: %s" : "Priskribo: %s",
    "Where: %s" : "Kie: %s",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "Invitation canceled" : "Invito nuligita",
    "Invitation updated" : "Invito ĝisdatigita",
    "Location:" : "Loko:",
    "Link:" : "Ligilo:",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "More options …" : "Pli da opcioj...",
    "More options at %s" : "Pli da opcioj je %s",
    "Contacts" : "Kontaktoj",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Via %s uzu HTTPS, por ke vi povu uzi CalDAV kaj CardDAV kun iOS aŭ macOS.",
    "Configures a CalDAV account" : "Agordas CalDAV-konton.",
    "Configures a CardDAV account" : "Agordas CardlDAV-konton.",
    "Tasks" : "Taskoj",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-finpunkto",
    "to" : "al",
    "Monday" : "lundo",
    "Tuesday" : "mardo",
    "Wednesday" : "merkredo",
    "Thursday" : "ĵaŭdo",
    "Friday" : "vendredo",
    "Saturday" : "sabato",
    "Sunday" : "dimanĉo",
    "Save" : "Konservi",
    "Calendar server" : "Kalendara servilo",
    "Send invitations to attendees" : "Sendi invitojn al ĉeestantoj",
    "Automatically generate a birthday calendar" : "Aŭtomate estigi datrevenan kalendaron",
    "Birthday calendars will be generated by a background job." : "Datrevenaj kalendaroj estos kreitaj de fona tasko.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Tial, ili disponeblos nur post kelke da tempo.",
    "Send notifications for events" : "Sendi sciigojn pri okazaĵoj",
    "Enable notifications for events via push" : "Ebligi sciigojn pri okazaĵoj per puŝteĥniko",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ankaŭ instalu la aplikaĵon {calendarappstoreopen}Kalendaro{linkclose} aŭ {calendardocopen}konektu vian surtablan kaj porteblan aparaton por eksinkronigi ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bv. certigi, ke via {emailopen}retpoŝtserva servilo{linkclose} estas bone agordita.",
    "There was an error updating your attendance status." : "Estis eraro dum ĝisdatigo de via ĉeesta stato.",
    "Please contact the organizer directly." : "Bv. senpere kontakti la organizanton.",
    "Are you accepting the invitation?" : "Ĉu vi akceptas la inviton?",
    "Tentative" : "Nekonfirmita",
    "Comment" : "Komento",
    "Your attendance was updated successfully." : "Via ĉeesto sukcese ĝisdatiĝis."
},
"nplurals=2; plural=(n != 1);");
